//  Diffusion Client Library for iOS, OS X and tvOS
//
//  Copyright (c) 2016 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;
#import <Diffusion/PTDiffusionStreamDelegate.h>
#import <Diffusion/PTDiffusionTopicUnsubscriptionReason.h>

@class PTDiffusionStream;
@class PTDiffusionTopicSpecification;

NS_ASSUME_NONNULL_BEGIN

/**
 @brief Methods implemented by classes handling streamed subscription events for
 value topics.

 This protocol defines optional methods implemented by classes wishing to
 receive streamed subscription events.
 
 @see PTDiffusionStreams

 @since 5.9
 */
@protocol PTDiffusionSubscriberStreamDelegate <PTDiffusionStreamDelegate>

@optional

/**
 A topic has been subscribed to.
 
 This is called when a client becomes subscribed to a topic.
 This method is also called when a stream is added that matches a topic to which
 the session is already subscribed.

 This will always be the first notification to the stream for a topic.
 
 Currently, topic properties are not available via this notification.
 
 @param stream The stream that received the update.
 
 @param topicPath The topic path to which the session has been subscribed.
 
 @param specification The specification for the subscribed topic.

 @since 5.9
 */
-(void)     diffusionStream:(PTDiffusionStream *)stream
    didSubscribeToTopicPath:(NSString *)topicPath
              specification:(PTDiffusionTopicSpecification *)specification;

/**
 A topic has been unsubscribed.
 
 @param stream The stream that received the update.
 
 @param topicPath The topic path from which the session has been unsubscribed.
 
 @param specification The specification for the unsubscribed topic.

 @param reason The reason for the unsubscription.

 @since 5.9
 */
-(void)         diffusionStream:(PTDiffusionStream *)stream
    didUnsubscribeFromTopicPath:(NSString *)topicPath
                  specification:(PTDiffusionTopicSpecification *)specification
                         reason:(PTDiffusionTopicUnsubscriptionReason)reason;

@end

NS_ASSUME_NONNULL_END
